Index: /branches/new_class_id/src/Makefile.am
===================================================================
--- /branches/new_class_id/src/Makefile.am	(revision 9835)
+++ /branches/new_class_id/src/Makefile.am	(revision 9836)
@@ -45,5 +45,5 @@
 		\
 		\
-		lib/util/loading/resource_manager.cc
+		lib/util/loading/old_resource_manager.cc
 
 noinst_HEADERS = \
Index: /branches/new_class_id/src/lib/graphics/importer/Makefile.am
===================================================================
--- /branches/new_class_id/src/lib/graphics/importer/Makefile.am	(revision 9835)
+++ /branches/new_class_id/src/lib/graphics/importer/Makefile.am	(revision 9836)
@@ -35,6 +35,6 @@
 		\
 		md2/md2Model.cc \
-		md2/resource_md2.cc \
-		\
+		md2/resource_md2.cc
+#		\
 		md3/md3_model.cc \
 		md3/md3_animation.cc \
Index: /branches/new_class_id/src/lib/graphics/importer/bsp_file.cc
===================================================================
--- /branches/new_class_id/src/lib/graphics/importer/bsp_file.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/graphics/importer/bsp_file.cc	(revision 9836)
@@ -22,5 +22,5 @@
 #include "bsp_tree_node.h"
 #include <fstream>
-#include "util/loading/new_resource_manager.h"
+#include "util/loading/resource_manager.h"
 
 #include <sys/stat.h>
@@ -466,5 +466,5 @@
     PRINTF(4)("BSP FILE: Name %s . \n", fileName);
 
-    absFileName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+    absFileName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
 
     if(File(absFileName).exists()) {
@@ -481,5 +481,5 @@
     strncat (fileName, ext, strlen(fileName));
 
-    absFileName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+    absFileName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
 
     if(File(absFileName).exists()) {
@@ -496,5 +496,5 @@
     strncat (fileName, ext, strlen(fileName));
 
-    absFileName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+    absFileName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
 
     if(File(absFileName).exists()) {
@@ -511,5 +511,5 @@
     strncat (fileName, ext, strlen(fileName));
 
-    absFileName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+    absFileName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
 
     if(File(absFileName).exists()) {
@@ -524,5 +524,5 @@
     strcpy(ext, ".TGA");
     strncat (fileName, ext, strlen(fileName));
-    absFileName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+    absFileName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
 
     if(File(absFileName).exists()/*stat( absFileName.c_str() , &results) == 0*/) {
@@ -537,5 +537,5 @@
     strcpy(ext, ".jpg");
     strncat (fileName, ext, strlen(fileName));
-    absFileName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+    absFileName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
     if(File(absFileName).exists()) {
       PRINTF(4)("BSP FILE: gefunden . \n");
@@ -551,5 +551,5 @@
     strcpy(ext, ".JPG");
     strncat (fileName, ext, strlen(fileName));
-    absFileName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+    absFileName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
     if(File(absFileName).exists()) {
       PRINTF(4)("BSP FILE: gefunden . \n");
@@ -566,5 +566,5 @@
     strcpy(ext, ".bmp");
     strncat (fileName, ext, strlen(fileName));
-    absFileName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+    absFileName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
 
     if(File(absFileName).exists()) {
@@ -580,5 +580,5 @@
     strcpy(ext, ".BMP");
     strncat (fileName, ext, strlen(fileName));
-    absFileName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+    absFileName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
 
     if(File(absFileName).exists()) {
@@ -611,5 +611,5 @@
   this->testSurf = NULL;
 
-  this->testSurf = IMG_Load(Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(mat).c_str());
+  this->testSurf = IMG_Load(Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(mat).c_str());
   if(this->testSurf != NULL) {
     if(this->testSurf->format->Amask != 0 ) tmpAMat.alpha = true;
Index: /branches/new_class_id/src/lib/graphics/importer/bsp_manager.cc
===================================================================
--- /branches/new_class_id/src/lib/graphics/importer/bsp_manager.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/graphics/importer/bsp_manager.cc	(revision 9836)
@@ -41,5 +41,5 @@
 #include "world_entity.h"
 
-#include "util/loading/new_resource_manager.h"
+#include "util/loading/resource_manager.h"
 #include "util/loading/load_param.h"
 #include "util/loading/factory.h"
@@ -92,5 +92,5 @@
   this->bspFile = new BspFile();
   this->bspFile->scale =  scale;
-  if(this->bspFile->read(Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName).c_str()) == -1)
+  if(this->bspFile->read(Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName).c_str()) == -1)
     return -1;
 
Index: /branches/new_class_id/src/lib/graphics/importer/media_container.cc
===================================================================
--- /branches/new_class_id/src/lib/graphics/importer/media_container.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/graphics/importer/media_container.cc	(revision 9836)
@@ -25,5 +25,5 @@
 #include "media_container.h"
 
-#include "util/loading/new_resource_manager.h"
+#include "util/loading/resource_manager.h"
 /* header for debug output */
 #include "debug.h"
@@ -91,5 +91,5 @@
     return false;
   // check whether file exists
-  if(!Resources::NewResourceManager::getInstance()->checkFileInMainPath(filename))
+  if(!Resources::ResourceManager::getInstance()->checkFileInMainPath(filename))
   {
     PRINTF(1)("Could not find %s\n", filename.c_str());
@@ -101,7 +101,7 @@
 
   // Open video file
-  if (av_open_input_file(&format_context, Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str(), NULL, 0, NULL) !=0 )
-  {
-    PRINTF(1)("Could not open %s\n", Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
+  if (av_open_input_file(&format_context, Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str(), NULL, 0, NULL) !=0 )
+  {
+    PRINTF(1)("Could not open %s\n", Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
     return false;
   }
@@ -110,5 +110,5 @@
   if (av_find_stream_info(format_context) < 0)
   {
-    PRINTF(1)("Could not find stream information in %s\n", Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
+    PRINTF(1)("Could not find stream information in %s\n", Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
     return false;
   }
@@ -119,5 +119,5 @@
   if(video_stream == -1)
   {
-    PRINTF(1)("Could not find a video stream in %s\n", Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
+    PRINTF(1)("Could not find a video stream in %s\n", Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
     return false;
   }
Index: /branches/new_class_id/src/lib/graphics/importer/movie_player.cc
===================================================================
--- /branches/new_class_id/src/lib/graphics/importer/movie_player.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/graphics/importer/movie_player.cc	(revision 9836)
@@ -24,5 +24,5 @@
 // include your own header
 #include "movie_player.h"
-#include "util/loading/new_resource_manager.h"
+#include "util/loading/resource_manager.h"
 
 // header for debug output
@@ -89,5 +89,5 @@
     return false;
   // check whether file exists
-  if(!Resources::NewResourceManager::getInstance()->checkFileInMainPath(filename))
+  if(!Resources::ResourceManager::getInstance()->checkFileInMainPath(filename))
   {
     PRINTF(1)("Could not find %s\n", filename.c_str());
@@ -99,7 +99,7 @@
 
   // Open video file
-  if (av_open_input_file(&format_context, Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str(), NULL, 0, NULL) !=0 )
-  {
-    PRINTF(1)("Could not open %s\n", Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
+  if (av_open_input_file(&format_context, Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str(), NULL, 0, NULL) !=0 )
+  {
+    PRINTF(1)("Could not open %s\n", Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
     return false;
   }
@@ -108,5 +108,5 @@
   if (av_find_stream_info(format_context) < 0)
   {
-    PRINTF(1)("Could not find stream information in %s\n", Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
+    PRINTF(1)("Could not find stream information in %s\n", Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
     return false;
   }
@@ -117,5 +117,5 @@
   if(video_stream == -1)
   {
-    PRINTF(1)("Could not find a video stream in %s\n", Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
+    PRINTF(1)("Could not find a video stream in %s\n", Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(filename).c_str());
     return false;
   }
Index: /branches/new_class_id/src/lib/graphics/text_engine/text.cc
===================================================================
--- /branches/new_class_id/src/lib/graphics/text_engine/text.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/graphics/text_engine/text.cc	(revision 9836)
@@ -18,5 +18,5 @@
 #include "text.h"
 #include "font.h"
-#include "loading/resource_manager.h"
+#include "loading/old_resource_manager.h"
 #include "debug.h"
 
Index: /branches/new_class_id/src/lib/gui/gl/glgui_handler.cc
===================================================================
--- /branches/new_class_id/src/lib/gui/gl/glgui_handler.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/gui/gl/glgui_handler.cc	(revision 9836)
@@ -23,5 +23,5 @@
 #include "glgui_cursor.h"
 
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 
 #include <cassert>
@@ -77,5 +77,5 @@
     this->_cursor->setMaxBorders(Vector2D(GraphicsEngine::getInstance()->getResolutionX(), GraphicsEngine::getInstance()->getResolutionY()));
 
-    _cursor->loadTextureSequence(Resources::NewResourceManager::getInstance()->mainGlobalPath().name() + "/" + "maps/reap_mouse/reap_mouse_##.png", 1, 49);
+    _cursor->loadTextureSequence(Resources::ResourceManager::getInstance()->mainGlobalPath().name() + "/" + "maps/reap_mouse/reap_mouse_##.png", 1, 49);
 
   }
Index: /branches/new_class_id/src/lib/gui/gl/glgui_widget.cc
===================================================================
--- /branches/new_class_id/src/lib/gui/gl/glgui_widget.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/gui/gl/glgui_widget.cc	(revision 9836)
@@ -25,5 +25,5 @@
 
 #include "loading/load_param.h"
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 
 namespace OrxGui
@@ -102,5 +102,5 @@
 
     if(GLGuiWidget::_defaultFont == NULL)
-      GLGuiWidget::_defaultFont = new Font(Resources::NewResourceManager::getInstance()->mainGlobalPath().name() + "/fonts/final_frontier.ttf", 20);
+      GLGuiWidget::_defaultFont = new Font(Resources::ResourceManager::getInstance()->mainGlobalPath().name() + "/fonts/final_frontier.ttf", 20);
 
     this->_font = *GLGuiWidget::_defaultFont;
Index: /branches/new_class_id/src/lib/network/monitor/network_stats_widget.cc
===================================================================
--- /branches/new_class_id/src/lib/network/monitor/network_stats_widget.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/network/monitor/network_stats_widget.cc	(revision 9836)
@@ -20,5 +20,5 @@
 #include "peer_info.h"
 
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 
 #include "multi_type.h"
@@ -56,5 +56,5 @@
 {
   if(_font == NULL)
-    _font = new Font(Resources::NewResourceManager::getInstance()->mainGlobalPath().name() + "/fonts/arial.ttf", 20);
+    _font = new Font(Resources::ResourceManager::getInstance()->mainGlobalPath().name() + "/fonts/arial.ttf", 20);
 
   //this->_name.setFont(*_font);
Index: /branches/new_class_id/src/lib/network/network_stream.cc
===================================================================
--- /branches/new_class_id/src/lib/network/network_stream.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/network/network_stream.cc	(revision 9836)
@@ -41,5 +41,5 @@
 
 #include "loading/factory.h"
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 
 #include "debug.h"
@@ -1299,5 +1299,5 @@
     length = remainingBytesToWriteToDict;
 
-  std::string fileName = Resources::NewResourceManager::getInstance()->mainGlobalPath().name();
+  std::string fileName = Resources::ResourceManager::getInstance()->mainGlobalPath().name();
   fileName += "/dicts/newdict";
 
Index: /branches/new_class_id/src/lib/network/proxy/network_settings.cc
===================================================================
--- /branches/new_class_id/src/lib/network/proxy/network_settings.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/network/proxy/network_settings.cc	(revision 9836)
@@ -22,5 +22,5 @@
 
 #include "loading/load_param.h"
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 #include "debug.h"
 
@@ -64,5 +64,5 @@
 void NetworkSettings::loadData()
 {
-  std::string fileName = Resources::NewResourceManager::getInstance()->mainGlobalPath().name();
+  std::string fileName = Resources::ResourceManager::getInstance()->mainGlobalPath().name();
   fileName += "configs/network_settings.conf";
 
Index: /branches/new_class_id/src/lib/network/zip.cc
===================================================================
--- /branches/new_class_id/src/lib/network/zip.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/network/zip.cc	(revision 9836)
@@ -15,5 +15,5 @@
 
 #include "zip.h"
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 #include "debug.h"
 
@@ -50,5 +50,5 @@
 int Zip::loadDictionary( std::string name )
 {
-  std::string fileName = Resources::NewResourceManager::getInstance()->mainGlobalPath().name();
+  std::string fileName = Resources::ResourceManager::getInstance()->mainGlobalPath().name();
   //PRINTF(0)("datadir: %s\n", fileName.c_str());
   fileName = fileName + "/dicts/" + name;
Index: /branches/new_class_id/src/lib/script_engine/script.cc
===================================================================
--- /branches/new_class_id/src/lib/script_engine/script.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/script_engine/script.cc	(revision 9836)
@@ -19,5 +19,5 @@
 #include "debug.h"
 
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 #include "loading/load_param.h"
 #include "parser/tinyxml/tinyxml.h"
@@ -100,5 +100,5 @@
 bool Script::loadFile(const std::string& filename)
  {
-   std::string filedest(Resources::NewResourceManager::getInstance()->mainGlobalPath().name());
+   std::string filedest(Resources::ResourceManager::getInstance()->mainGlobalPath().name());
    filedest += "scripts/" + filename;
 
Index: /branches/new_class_id/src/lib/shell/shell_completion_plugin.cc
===================================================================
--- /branches/new_class_id/src/lib/shell/shell_completion_plugin.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/shell/shell_completion_plugin.cc	(revision 9836)
@@ -22,5 +22,5 @@
 
 #include "helper_functions.h"
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 
 #include "filesys/directory.h"
@@ -97,5 +97,5 @@
     if (completionBegin.empty()) // if we do not yet have the beginning of the line, start with the chosen startDir.
     {
-      dir.setFileName(Resources::NewResourceManager::getInstance()->mainGlobalPath().name() + this->_subDir);
+      dir.setFileName(Resources::ResourceManager::getInstance()->mainGlobalPath().name() + this->_subDir);
       dir.open();
       for(unsigned int i = 0; i < dir.fileCount(); i++ )
@@ -112,5 +112,5 @@
         directoryName = completionBegin.substr(0, pos);
 
-      dir.setFileName(Resources::NewResourceManager::getInstance()->mainGlobalPath().name() + directoryName);
+      dir.setFileName(Resources::ResourceManager::getInstance()->mainGlobalPath().name() + directoryName);
       dir.open();
 
@@ -135,7 +135,7 @@
           continue;
         }
-	printf("%s\n", (Resources::NewResourceManager::getInstance()->mainGlobalPath().name() + fileName).c_str());
+	printf("%s\n", (Resources::ResourceManager::getInstance()->mainGlobalPath().name() + fileName).c_str());
         if (!nocaseCmp(completionBegin, fileName, completionBegin.size()) &&
-	     Resources::NewResourceManager::getInstance()->checkFileInMainPath(fileName))
+	     Resources::ResourceManager::getInstance()->checkFileInMainPath(fileName))
         {
           printf("Dir %s\n", fileName.c_str());
Index: /branches/new_class_id/src/lib/shell/some_shell_commands.cc
===================================================================
--- /branches/new_class_id/src/lib/shell/some_shell_commands.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/shell/some_shell_commands.cc	(revision 9836)
@@ -52,7 +52,7 @@
 ->completionPlugin(0, CompletorFileSystem());
 
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 namespace Resources
-{SHELL_COMMAND(debug, NewResourceManager, debug);}
+{SHELL_COMMAND(debug, ResourceManager, debug);}
 
 #include "loading/load_param_class_description.h"
Index: /branches/new_class_id/src/lib/util/Makefile.am
===================================================================
--- /branches/new_class_id/src/lib/util/Makefile.am	(revision 9835)
+++ /branches/new_class_id/src/lib/util/Makefile.am	(revision 9836)
@@ -15,5 +15,5 @@
 		multi_type.cc \
 		\
-		loading/new_resource_manager.cc \
+		loading/resource_manager.cc \
 		loading/resource.cc \
 		loading/game_loader.cc \
@@ -66,5 +66,4 @@
 		\
 		loading/resource_manager.h \
-		loading/new_resource_manager.h \
 		loading/resource.h \
 		loading/game_loader.h \
Index: /branches/new_class_id/src/lib/util/loading/game_loader.cc
===================================================================
--- /branches/new_class_id/src/lib/util/loading/game_loader.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/util/loading/game_loader.cc	(revision 9836)
@@ -20,5 +20,5 @@
 #include "game_loader.h"
 #include "util/loading/load_param.h"
-#include "util/loading/new_resource_manager.h"
+#include "util/loading/resource_manager.h"
 #include "debug.h"
 #include "campaign.h"
@@ -83,5 +83,5 @@
 {
   ErrorMessage errorCode;
-  std::string campaignName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+  std::string campaignName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
   if (!campaignName.empty())
   {
@@ -103,5 +103,5 @@
 {
   ErrorMessage errorCode;
-  std::string campaignName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+  std::string campaignName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
   if (!campaignName.empty())
   {
Index: /branches/new_class_id/src/lib/util/loading/old_resource_manager.cc
===================================================================
--- /branches/new_class_id/src/lib/util/loading/old_resource_manager.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/util/loading/old_resource_manager.cc	(revision 9836)
@@ -16,5 +16,5 @@
 #define DEBUG_SPECIAL_MODULE DEBUG_MODULE_LOAD
 
-#include "util/loading/resource_manager.h"
+#include "old_resource_manager.h"
 #include "substring.h"
 #include "debug.h"
@@ -411,5 +411,5 @@
         tmpResource->param[0] = param0;
         tmpResource->param[1] = param1;
-        tmpResource->pointer = new md3::MD3Data(fullName, tmpResource->param[0].getCString(), tmpResource->param[1].getFloat());
+//        tmpResource->pointer = new md3::MD3Data(fullName, tmpResource->param[0].getCString(), tmpResource->param[1].getFloat());
       }
       break;
@@ -419,5 +419,5 @@
         tmpResource->param[0] = param0;
         tmpResource->param[1] = param1;
-        tmpResource->pointer = new md3::MD3AnimationCfg(fullName);
+//        tmpResource->pointer = new md3::MD3AnimationCfg(fullName);
       }
       break;
Index: /branches/new_class_id/src/lib/util/loading/old_resource_manager.h
===================================================================
--- /branches/new_class_id/src/lib/util/loading/old_resource_manager.h	(revision 9835)
+++ /branches/new_class_id/src/lib/util/loading/old_resource_manager.h	(revision 9836)
@@ -17,6 +17,6 @@
 */
 
-#ifndef _RESOURCE_MANAGER_H
-#define _RESOURCE_MANAGER_H
+#ifndef _OLD_RESOURCE_MANAGER_H
+#define _OLD_RESOURCE_MANAGER_H
 
 #include "base_object.h"
Index: /branches/new_class_id/src/lib/util/loading/resource.cc
===================================================================
--- /branches/new_class_id/src/lib/util/loading/resource.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/util/loading/resource.cc	(revision 9836)
@@ -17,5 +17,5 @@
 
 #include "resource.h"
-#include "new_resource_manager.h"
+#include "resource_manager.h"
 
 #include "debug.h"
@@ -47,9 +47,9 @@
   std::string NewResource::locateFile(const std::string& fileName) const
   {
-    if ((NewResourceManager::getInstance()->mainGlobalPath() + File(fileName)).exists() )
-      return (NewResourceManager::getInstance()->mainGlobalPath() + File(fileName)).name();
+    if ((ResourceManager::getInstance()->mainGlobalPath() + File(fileName)).exists() )
+      return (ResourceManager::getInstance()->mainGlobalPath() + File(fileName)).name();
 
     std::string locatedFile;
-    locatedFile = locateFileInSubDir(NewResourceManager::getInstance()->mainGlobalPath(), fileName);
+    locatedFile = locateFileInSubDir(ResourceManager::getInstance()->mainGlobalPath(), fileName);
     if (!locatedFile.empty())
     {
@@ -61,5 +61,5 @@
       return fileName;
 
-    return (NewResourceManager::getInstance()->mainGlobalPath() + File(fileName)).name();
+    return (ResourceManager::getInstance()->mainGlobalPath() + File(fileName)).name();
   }
 
@@ -115,10 +115,10 @@
   KeepLevel::KeepLevel(const std::string& keepLevelName)
   {
-    this->_keepLevel = NewResourceManager::getInstance()->getKeepLevelID(keepLevelName);
+    this->_keepLevel = ResourceManager::getInstance()->getKeepLevelID(keepLevelName);
   }
 
   const std::string& KeepLevel::name() const
   {
-    return NewResourceManager::getInstance()->getKeepLevelName(this->_keepLevel);
+    return ResourceManager::getInstance()->getKeepLevelName(this->_keepLevel);
   }
 
@@ -141,5 +141,5 @@
       : _id(-1), _typeName(typeName)
   {
-    NewResourceManager::getInstance()->registerType(this);
+    ResourceManager::getInstance()->registerType(this);
     PRINTF(4)("Created ResourceType '%s'\n", typeName.c_str());
   }
@@ -147,5 +147,5 @@
   Type::~Type()
   {
-    NewResourceManager::getInstance()->unregisterType(this);
+    ResourceManager::getInstance()->unregisterType(this);
   }
 
Index: /branches/new_class_id/src/lib/util/loading/resource_manager.h
===================================================================
--- /branches/new_class_id/src/lib/util/loading/resource_manager.h	(revision 9835)
+++ /branches/new_class_id/src/lib/util/loading/resource_manager.h	(revision 9836)
@@ -1,8 +1,8 @@
 /*!
- * @file new_resource_manager.h
+ * @file resource_manager.h
  */
 
-#ifndef _NEW_RESOURCE_MANAGER_H
-#define _NEW_RESOURCE_MANAGER_H
+#ifndef _RESOURCE_MANAGER_H
+#define _RESOURCE_MANAGER_H
 
 #include "resource.h"
@@ -13,10 +13,10 @@
 {
 
-  class NewResourceManager : public BaseObject
+  class ResourceManager : public BaseObject
   {
-    ObjectListDeclaration(NewResourceManager);
+    ObjectListDeclaration(ResourceManager);
   public:
     /** @returns a Pointer to the only object of this Class */
-    inline static NewResourceManager* getInstance() { if (!_singletonRef) _singletonRef = new NewResourceManager();  return _singletonRef; };
+    inline static ResourceManager* getInstance() { if (!_singletonRef) _singletonRef = new ResourceManager();  return _singletonRef; };
     /** @brief deletes the Instance if it exists. */
     inline static void deleteInstance() { if (_singletonRef) delete _singletonRef; };
@@ -54,9 +54,9 @@
     static bool isInDataDir(const std::string& fileName);
   private:
-    NewResourceManager();
-    virtual ~NewResourceManager();
+    ResourceManager();
+    virtual ~ResourceManager();
 
   private:
-    static NewResourceManager*         _singletonRef;       //!< singleton Reference
+    static ResourceManager*         _singletonRef;       //!< singleton Reference
 
     Directory                          _mainGlobalPath;     //!< The main include directory (default at "./")
Index: /branches/new_class_id/src/orxonox.cc
===================================================================
--- /branches/new_class_id/src/orxonox.cc	(revision 9835)
+++ /branches/new_class_id/src/orxonox.cc	(revision 9836)
@@ -41,5 +41,5 @@
 #include "sound_engine.h"
 #include "util/loading/resource_manager.h"
-#include "util/loading/new_resource_manager.h"
+#include "util/loading/old_resource_manager.h"
 
 #include "cd_engine.h"
@@ -129,5 +129,5 @@
 
   // handlers
-  Resources::NewResourceManager::deleteInstance(); // deletes the Resource Manager
+  Resources::ResourceManager::deleteInstance(); // deletes the Resource Manager
 
   // engines
@@ -257,5 +257,5 @@
   GraphicsEngine::getInstance()->initFromPreferences();
 
-  std::string iconName = ResourceManager::getFullName("pictures/fighter-top-32x32.bmp");
+  std::string iconName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath("pictures/fighter-top-32x32.bmp");
   if (!iconName.empty())
   {
@@ -341,16 +341,16 @@
   if ((dataPath = Preferences::getInstance()->getString(CONFIG_SECTION_GENERAL, CONFIG_NAME_DATADIR, ""))!= "")
   {
-    Resources::NewResourceManager::getInstance()->setMainGlobalPath(dataPath) ;
-    if(!Resources::NewResourceManager::getInstance()->checkFileInMainPath(File(DEFAULT_DATA_DIR_CHECKFILE)))
+    Resources::ResourceManager::getInstance()->setMainGlobalPath(dataPath) ;
+    if(!Resources::ResourceManager::getInstance()->checkFileInMainPath(File(DEFAULT_DATA_DIR_CHECKFILE)))
     {
       PRINTF(1)("Data Could not be located in %s\n", dataPath.c_str());
     }
   }
-  while (!Resources::NewResourceManager::getInstance()->checkFileInMainPath(File(DEFAULT_DATA_DIR_CHECKFILE)))
+  while (!Resources::ResourceManager::getInstance()->checkFileInMainPath(File(DEFAULT_DATA_DIR_CHECKFILE)))
   {
 
     PRINTF(1)("The DataDirectory %s could not be verified\n\nh" \
               "!!!  Please Change in File %s Section %s Entry %s to a suitable value !!!\n",
-              Resources::NewResourceManager::getInstance()->mainGlobalPath().name().c_str(),
+              Resources::ResourceManager::getInstance()->mainGlobalPath().name().c_str(),
               this->configFileName.c_str(),
               CONFIG_SECTION_GENERAL,
@@ -361,5 +361,5 @@
       return(-1);
     delete gui;
-    Resources::NewResourceManager::getInstance()->setMainGlobalPath(Preferences::getInstance()->getString(CONFIG_SECTION_GENERAL, CONFIG_NAME_DATADIR, ""));
+    Resources::ResourceManager::getInstance()->setMainGlobalPath(Preferences::getInstance()->getString(CONFIG_SECTION_GENERAL, CONFIG_NAME_DATADIR, ""));
   }
 
@@ -367,17 +367,17 @@
 
   //! @todo this is a hack and should be loadable
-  Resources::NewResourceManager::getInstance()->addResourceSubPath("Texture", "maps");
-  Resources::NewResourceManager::getInstance()->addResourceSubPath("Texture", "pictures");
-
-  Resources::NewResourceManager::getInstance()->addResourceSubPath("SoundBuffer", "sound");
-  Resources::NewResourceManager::getInstance()->addResourceSubPath("SoundBuffer", "music");
-
-  Resources::NewResourceManager::getInstance()->addKeepLevelName("Imediately");
-  Resources::NewResourceManager::getInstance()->addKeepLevelName("LevelEnd");
-  Resources::NewResourceManager::getInstance()->addKeepLevelName("CampaignEnd");
-  Resources::NewResourceManager::getInstance()->addKeepLevelName("GameEnd");
-
-
-  Resources::NewResourceManager::getInstance()->debug();
+  Resources::ResourceManager::getInstance()->addResourceSubPath("Texture", "maps");
+  Resources::ResourceManager::getInstance()->addResourceSubPath("Texture", "pictures");
+
+  Resources::ResourceManager::getInstance()->addResourceSubPath("SoundBuffer", "sound");
+  Resources::ResourceManager::getInstance()->addResourceSubPath("SoundBuffer", "music");
+
+  Resources::ResourceManager::getInstance()->addKeepLevelName("Imediately");
+  Resources::ResourceManager::getInstance()->addKeepLevelName("LevelEnd");
+  Resources::ResourceManager::getInstance()->addKeepLevelName("CampaignEnd");
+  Resources::ResourceManager::getInstance()->addKeepLevelName("GameEnd");
+
+
+  Resources::ResourceManager::getInstance()->debug();
   //  DynamicLoader::loadDyLib("libtest.so");
   return 0;
Index: /branches/new_class_id/src/story_entities/game_world_data.cc
===================================================================
--- /branches/new_class_id/src/story_entities/game_world_data.cc	(revision 9835)
+++ /branches/new_class_id/src/story_entities/game_world_data.cc	(revision 9836)
@@ -25,5 +25,5 @@
 
 #include "util/loading/game_loader.h"
-#include "util/loading/new_resource_manager.h"
+#include "util/loading/resource_manager.h"
 
 #include "world_entity.h"
@@ -379,5 +379,5 @@
   {
     PRINTF(3)("Setting Sound Track to %s\n", name.c_str());
-    std::string oggFile = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(name);
+    std::string oggFile = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(name);
     this->music = new OrxSound::OggPlayer(oggFile);
     if (this->localPlayer != NULL)
Index: /branches/new_class_id/src/story_entities/story_entity.cc
===================================================================
--- /branches/new_class_id/src/story_entities/story_entity.cc	(revision 9835)
+++ /branches/new_class_id/src/story_entities/story_entity.cc	(revision 9836)
@@ -23,5 +23,5 @@
 
 #include "loading/load_param.h"
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 
 #include "debug.h"
@@ -107,5 +107,5 @@
   }
   else
-    this->loadFile = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
+    this->loadFile = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(fileName);
 
   this->grabWorldInfo();
Index: /branches/new_class_id/src/world_entities/bsp_entity.cc
===================================================================
--- /branches/new_class_id/src/world_entities/bsp_entity.cc	(revision 9835)
+++ /branches/new_class_id/src/world_entities/bsp_entity.cc	(revision 9836)
@@ -17,5 +17,5 @@
 
 #include "debug.h"
-#include "loading/new_resource_manager.h"
+#include "loading/resource_manager.h"
 
 #include "class_id_DEPRECATED.h"
@@ -71,5 +71,5 @@
 
   // Check wether file exists....
-  if ( File(Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(name)).exists()  ) {
+  if ( File(Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(name)).exists()  ) {
 
     this->bspManager = new BspManager(this);
Index: /branches/new_class_id/src/world_entities/terrain.cc
===================================================================
--- /branches/new_class_id/src/world_entities/terrain.cc	(revision 9835)
+++ /branches/new_class_id/src/world_entities/terrain.cc	(revision 9836)
@@ -18,5 +18,5 @@
 #include "terrain.h"
 
-#include "util/loading/new_resource_manager.h"
+#include "util/loading/resource_manager.h"
 #include "util/loading/load_param.h"
 #include "util/loading/factory.h"
@@ -144,6 +144,6 @@
   this->heightMap = NULL;
 
-  std::string hmName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(heightMapFile);
-  std::string hmColorName = Resources::NewResourceManager::getInstance()->prependAbsoluteMainPath(colorMap);
+  std::string hmName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(heightMapFile);
+  std::string hmColorName = Resources::ResourceManager::getInstance()->prependAbsoluteMainPath(colorMap);
 
 
Index: /branches/new_class_id/src/world_entities/world_entity.cc
===================================================================
--- /branches/new_class_id/src/world_entities/world_entity.cc	(revision 9835)
+++ /branches/new_class_id/src/world_entities/world_entity.cc	(revision 9836)
@@ -20,5 +20,5 @@
 #include "shell_command.h"
 
-#include "util/loading/new_resource_manager.h"
+#include "util/loading/resource_manager.h"
 #include "resource_obj.h"
 #include "md2/md2Model.h"
@@ -162,7 +162,7 @@
   std::string name = fileName;
 
-  if (  name.find( Resources::NewResourceManager::getInstance()->mainGlobalPath().name() ) == 0 )
-  {
-    name.erase(Resources::NewResourceManager::getInstance()->mainGlobalPath().name().size());
+  if (  name.find( Resources::ResourceManager::getInstance()->mainGlobalPath().name() ) == 0 )
+  {
+    name.erase(Resources::ResourceManager::getInstance()->mainGlobalPath().name().size());
   }
 
@@ -180,5 +180,5 @@
       {
         lodFile[offset] = 48+(int)i;
-        if (Resources::NewResourceManager::getInstance()->checkFileInMainPath( lodFile))
+        if (Resources::ResourceManager::getInstance()->checkFileInMainPath( lodFile))
           this->loadModel(lodFile, scaling, i);
       }
@@ -220,6 +220,6 @@
     {
       PRINTF(4)("fetching MD3 file: %s\n", fileName.c_str());
-      Model* m = new md3::MD3Model(fileName, this->scaling);
-      this->setModel(m, 0);
+//      Model* m = new md3::MD3Model(fileName, this->scaling);
+//      this->setModel(m, 0);
 
       //       if( m != NULL)

Index: /branches/new_class_id/src/lib/util/loading/resource_manager.cc
===================================================================
--- /branches/new_class_id/src/lib/util/loading/resource_manager.cc	(revision 9835)
+++ /branches/new_class_id/src/lib/util/loading/resource_manager.cc	(revision 9836)
@@ -16,5 +16,5 @@
 #define DEBUG_SPECIAL_MODULE DEBUG_MODULE_LOAD
 
-#include "new_resource_manager.h"
+#include "resource_manager.h"
 #include "debug.h"
 
@@ -25,7 +25,7 @@
 namespace Resources
 {
-  ObjectListDefinition(NewResourceManager);
-  //! Singleton Reference to the NewResourceManager
-  NewResourceManager* NewResourceManager::_singletonRef = NULL;
+  ObjectListDefinition(ResourceManager);
+  //! Singleton Reference to the ResourceManager
+  ResourceManager* ResourceManager::_singletonRef = NULL;
 
 
@@ -33,8 +33,8 @@
    * @brief standard constructor
   */
-  NewResourceManager::NewResourceManager ()
+  ResourceManager::ResourceManager ()
   {
-    this->registerObject(this, NewResourceManager::_objectList);
-    this->setName("NewResourceManager");
+    this->registerObject(this, ResourceManager::_objectList);
+    this->setName("ResourceManager");
     this->_mainGlobalPath = Directory("./");
   }
@@ -44,5 +44,5 @@
    * @brief standard destructor
   */
-  NewResourceManager::~NewResourceManager ()
+  ResourceManager::~ResourceManager ()
   {
     // deleting the Resources-List
@@ -52,5 +52,5 @@
     //     PRINTF(1)("Not removed all Resources, since there are still %d resources registered\n", this->resourceList.size());
 
-    NewResourceManager::_singletonRef = NULL;
+    ResourceManager::_singletonRef = NULL;
   }
 
@@ -58,5 +58,5 @@
 
 
-  void NewResourceManager::registerType(Resources::Type* type)
+  void ResourceManager::registerType(Resources::Type* type)
   {
     if(type->id() == -1)
@@ -68,5 +68,5 @@
   }
 
-  void NewResourceManager::unregisterType(Resources::Type* type)
+  void ResourceManager::unregisterType(Resources::Type* type)
   {
     std::vector<Resources::Type*>::iterator it = std::find (this->_resourceTypes.begin(), this->_resourceTypes.end(), type);
@@ -79,5 +79,5 @@
 
 
-  void NewResourceManager::setMainGlobalPath(const Directory& directory)
+  void ResourceManager::setMainGlobalPath(const Directory& directory)
   {
     this->_mainGlobalPath = directory;
@@ -85,5 +85,5 @@
   }
 
-  void NewResourceManager::addGlobalPath(const Directory& directory)
+  void ResourceManager::addGlobalPath(const Directory& directory)
   {
     std::vector<Directory>::const_iterator it = std::find(this->_globalPaths.begin(), this->_globalPaths.end(), directory);
@@ -93,5 +93,5 @@
 
 
-  bool NewResourceManager::addResourcePath(const std::string& resourceName, const std::string& pathName)
+  bool ResourceManager::addResourcePath(const std::string& resourceName, const std::string& pathName)
   {
     std::vector<Resources::Type*>::iterator it;
@@ -103,5 +103,5 @@
   }
 
-  bool NewResourceManager::addResourceSubPath(const std::string& resourceName, const std::string& pathName)
+  bool ResourceManager::addResourceSubPath(const std::string& resourceName, const std::string& pathName)
   {
     std::vector<Resources::Type*>::iterator it;
@@ -115,10 +115,10 @@
 
 
-  bool NewResourceManager::checkFileInMainPath(const File& fileInside)
+  bool ResourceManager::checkFileInMainPath(const File& fileInside)
   {
     return (this->_mainGlobalPath + fileInside).exists();
   }
 
-  std::string NewResourceManager::prependAbsoluteMainPath(const std::string& fileName)
+  std::string ResourceManager::prependAbsoluteMainPath(const std::string& fileName)
   {
     return (this->_mainGlobalPath + File(fileName)).name();
@@ -126,5 +126,5 @@
 
 
-  unsigned int NewResourceManager::addKeepLevelName(const std::string& keepLevelName)
+  unsigned int ResourceManager::addKeepLevelName(const std::string& keepLevelName)
   {
     this->_keepLevelNames.push_back(keepLevelName);
@@ -132,5 +132,5 @@
   }
 
-  unsigned int NewResourceManager::getKeepLevelID(const std::string& keepLevelName) const
+  unsigned int ResourceManager::getKeepLevelID(const std::string& keepLevelName) const
   {
     for (unsigned int i = 0; i < this->_keepLevelNames.size(); ++i)
@@ -142,5 +142,5 @@
   }
 
-  const std::string& NewResourceManager::getKeepLevelName(unsigned int keepLevelID) const
+  const std::string& ResourceManager::getKeepLevelName(unsigned int keepLevelID) const
   {
     assert(keepLevelID < this->_keepLevelNames.size());
@@ -150,7 +150,7 @@
 
   /**
    * @brief outputs debug information about the NewResourceManager
    */
-  void NewResourceManager::debug() const
+  void ResourceManager::debug() const
   {
     PRINT(0)("=RM===================================\n");
@@ -150,7 +150,7 @@
 
   /**
-   * @brief outputs debug information about the NewResourceManager
+   * @brief outputs debug information about the ResourceManager
    */